@@ -33,7 +33,7 @@ from .process import Process, cleanIntermediate, relocateOutputs
 from .provenance_profile import ProvenanceProfile
 from .task_queue import TaskQueue
 from .update import ORIGINAL_CWLVERSION
-from .utils import CWLObjectType, CWLOutputType, JobsType
+from .utils import CWLObjectType, JobsType
 from .workflow import Workflow
 from .workflow_job import WorkflowJob, WorkflowJobStep
 
@@ -158,7 +158,7 @@ class JobExecutor(metaclass=ABCMeta):
             )
 
         if runtime_context.rm_tmpdir:
-            if runtime_context.cachedir is None:
+            if not runtime_context.cachedir:
                 output_dirs = self.output_dirs  # type: Iterable[str]
             else:
                 output_dirs = filter(
