@@ -46,7 +46,9 @@ if TYPE_CHECKING:
     from .workflow import Workflow, WorkflowStep
 
 
-class WorkflowJobStep(object):
+class WorkflowJobStep:
+    """Generated for each step in Workflow.steps()."""
+
     def __init__(self, step: "WorkflowStep") -> None:
         """Initialize this WorkflowJobStep."""
         self.step = step
@@ -71,11 +73,12 @@ class WorkflowJobStep(object):
 
         _logger.info("[%s] start", self.name)
 
-        for j in self.step.job(joborder, output_callback, runtimeContext):
-            yield j
+        yield from self.step.job(joborder, output_callback, runtimeContext)
 
 
-class ReceiveScatterOutput(object):
+class ReceiveScatterOutput:
+    """Produced by the scatter generators."""
+
     def __init__(
         self,
         output_callback: ScatterOutputCallbackType,
@@ -438,7 +441,7 @@ def object_from_state(
                         break
                 if not found:
                     raise WorkflowException(
-                        u"All sources for '%s' are null" % (shortname(original_id))
+                        "All sources for '%s' are null" % (shortname(original_id))
                     )
             elif inp["pickValue"] == "the_only_non_null":
                 found = False
@@ -446,14 +449,14 @@ def object_from_state(
                     if v is not None:
                         if found:
                             raise WorkflowException(
-                                u"Expected only one source for '%s' to be non-null, got %s"
+                                "Expected only one source for '%s' to be non-null, got %s"
                                 % (shortname(original_id), seq)
                             )
                         found = True
                         inputobj[iid] = v
                 if not found:
                     raise WorkflowException(
-                        u"All sources for '%s' are null" % (shortname(original_id))
+                        "All sources for '%s' are null" % (shortname(original_id))
                     )
             elif inp["pickValue"] == "all_non_null":
                 inputobj[iid] = [v for v in seq if v is not None]
@@ -469,7 +472,9 @@ def object_from_state(
     return inputobj
 
 
-class WorkflowJob(object):
+class WorkflowJob:
+    """Generates steps from the Workflow."""
+
     def __init__(self, workflow: "Workflow", runtimeContext: RuntimeContext) -> None:
         """Initialize this WorkflowJob."""
         self.workflow = workflow
@@ -597,7 +602,11 @@ class WorkflowJob(object):
         final_output_callback: Optional[OutputCallbackType],
         runtimeContext: RuntimeContext,
     ) -> JobsGeneratorType:
-
+        container_engine = "docker"
+        if runtimeContext.podman:
+            container_engine = "podman"
+        elif runtimeContext.singularity:
+            container_engine = "singularity"
         if step.submitted:
             return
 
@@ -628,9 +637,9 @@ class WorkflowJob(object):
                 i["id"]: i["valueFrom"] for i in step.tool["inputs"] if "valueFrom" in i
             }
 
-            loadContents = set(
+            loadContents = {
                 i["id"] for i in step.tool["inputs"] if i.get("loadContents")
-            )
+            }
 
             if len(valueFrom) > 0 and not bool(
                 self.workflow.get_requirement("StepInputExpressionRequirement")[0]
@@ -659,6 +668,7 @@ class WorkflowJob(object):
                         adjustDirObjs(
                             v, functools.partial(get_listing, fs_access, recursive=True)
                         )
+
                         return expression.do_eval(
                             valueFrom[k],
                             shortio,
@@ -670,6 +680,7 @@ class WorkflowJob(object):
                             debug=runtimeContext.debug,
                             js_console=runtimeContext.js_console,
                             timeout=runtimeContext.eval_timeout,
+                            container_engine=container_engine,
                         )
                     return v
 
@@ -687,6 +698,7 @@ class WorkflowJob(object):
                         debug=runtimeContext.debug,
                         js_console=runtimeContext.js_console,
                         timeout=runtimeContext.eval_timeout,
+                        container_engine=container_engine,
                     )
                     if whenval is True:
                         pass
@@ -745,28 +757,27 @@ class WorkflowJob(object):
             else:
                 if _logger.isEnabledFor(logging.DEBUG):
                     _logger.debug(
-                        u"[%s] job input %s", step.name, json_dumps(inputobj, indent=4)
+                        "[%s] job input %s", step.name, json_dumps(inputobj, indent=4)
                     )
 
                 inputobj = postScatterEval(inputobj)
                 if inputobj is not None:
                     if _logger.isEnabledFor(logging.DEBUG):
                         _logger.debug(
-                            u"[%s] evaluated job input to %s",
+                            "[%s] evaluated job input to %s",
                             step.name,
                             json_dumps(inputobj, indent=4),
                         )
                     jobs = step.job(inputobj, callback, runtimeContext)
                 else:
-                    _logger.info(u"[%s] will be skipped", step.name)
+                    _logger.info("[%s] will be skipped", step.name)
                     callback({k["id"]: None for k in outputparms}, "skipped")
                     step.completed = True
                     jobs = (_ for _ in ())
 
             step.submitted = True
 
-            for j in jobs:
-                yield j
+            yield from jobs
         except WorkflowException:
             raise
         except Exception:
@@ -796,14 +807,10 @@ class WorkflowJob(object):
 
         runtimeContext = runtimeContext.copy()
         runtimeContext.outdir = None
+        debug = runtimeContext.debug
 
         for index, inp in enumerate(self.tool["inputs"]):
-            with SourceLine(
-                self.tool["inputs"],
-                index,
-                WorkflowException,
-                _logger.isEnabledFor(logging.DEBUG),
-            ):
+            with SourceLine(self.tool["inputs"], index, WorkflowException, debug):
                 inp_id = shortname(inp["id"])
                 if inp_id in joborder:
                     self.state[inp["id"]] = WorkflowStateItem(
