@@ -539,97 +539,6 @@ def test_scandeps_defaults_with_secondaryfiles() -> None:
     ].endswith(os.path.join("tests", "wf", "indir1"))
 
 
-def test_input_deps() -> None:
-    stream = StringIO()
-
-    main(
-        [
-            "--print-input-deps",
-            get_data("tests/wf/count-lines1-wf.cwl"),
-            get_data("tests/wf/wc-job.json"),
-        ],
-        stdout=stream,
-    )
-
-    expected = {
-        "class": "File",
-        "location": "wc-job.json",
-        "format": CWL_IANA,
-        "secondaryFiles": [
-            {
-                "class": "File",
-                "location": "whale.txt",
-                "basename": "whale.txt",
-                "nameroot": "whale",
-                "nameext": ".txt",
-            }
-        ],
-    }
-    assert json.loads(stream.getvalue()) == expected
-
-
-def test_input_deps_cmdline_opts() -> None:
-    stream = StringIO()
-
-    main(
-        [
-            "--print-input-deps",
-            get_data("tests/wf/count-lines1-wf.cwl"),
-            "--file1",
-            get_data("tests/wf/whale.txt"),
-        ],
-        stdout=stream,
-    )
-    expected = {
-        "class": "File",
-        "location": "",
-        "format": CWL_IANA,
-        "secondaryFiles": [
-            {
-                "class": "File",
-                "location": "whale.txt",
-                "basename": "whale.txt",
-                "nameroot": "whale",
-                "nameext": ".txt",
-            }
-        ],
-    }
-    assert json.loads(stream.getvalue()) == expected
-
-
-def test_input_deps_cmdline_opts_relative_deps_cwd() -> None:
-    stream = StringIO()
-
-    data_path = get_data("tests/wf/whale.txt")
-    main(
-        [
-            "--print-input-deps",
-            "--relative-deps",
-            "cwd",
-            get_data("tests/wf/count-lines1-wf.cwl"),
-            "--file1",
-            data_path,
-        ],
-        stdout=stream,
-    )
-
-    goal = {
-        "class": "File",
-        "location": "",
-        "format": CWL_IANA,
-        "secondaryFiles": [
-            {
-                "class": "File",
-                "location": str(Path(os.path.relpath(data_path, os.path.curdir))),
-                "basename": "whale.txt",
-                "nameroot": "whale",
-                "nameext": ".txt",
-            }
-        ],
-    }
-    assert json.loads(stream.getvalue()) == goal
-
-
 def test_dedupe() -> None:
     not_deduped = [
         {"class": "File", "location": "file:///example/a"},
